@@ -4,6 +4,7 @@ weighted_quantile <- function(x, w, probs, na.rm = FALSE)
     dat <- .check_data_weights(x, w, na.rm)
     if (is.null(dat))
         return(NA)
+
     if (any(probs < 0) || any(probs > 1))
         stop("Argument 'probs' not in [0, 1]\n", call. = FALSE)
     res <- NULL
@@ -14,5 +15,5 @@ weighted_quantile <- function(x, w, probs, na.rm = FALSE)
         res <- c(res, tmp$q)
     }
     names(res) <- paste0(probs * 100, "%")
-    return(res)
+    res
 }
