@@ -15,12 +15,15 @@
 #include "wquantile.h"
 #include "psifunctions.h"
 #include "mallows.h"
-#include "constants.h"
+#include "regression_scale.h"
+#include "regression_data.h"
 
 #ifndef _REGRESSION_H
 #define _REGRESSION_H
 
 // prototypes for the functions
 void rwlslm(double*, double*, double*, double*, double*, double*, int*, int*,
-    double*, double*, double*, double*, int*, int*, int*, int*, int*);
+    double*, double*, double*, double*, int*, int*, int*, int*, int*, int*,
+    int*);
+void wlslm(double*, double*, double*, double*, int*, int*, double*, double*);
 #endif
