@@ -1,7 +1,7 @@
 /* Functions to compute the covariance matrix of weighted (generalized)
    regression M-estimators
 
-   Copyright (C) 2020-21 Tobias Schoch (e-mail: tobias.schoch@gmail.com)
+   Copyright (C) 2020-24 Tobias Schoch (e-mail: tobias.schoch@gmail.com)
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -73,8 +73,18 @@ void cov_reg_model(double *resid, double *x, double *xwgt, double *robwgt,
     dat->xwgt = xwgt;
 
     // initialize and populate structure with work arrays
-    double* restrict work_x = (double*) Calloc(*n * *p, double);
-    double* restrict work_y = (double*) Calloc(*n, double);
+    double* restrict work_x = (double*) R_Calloc(*n * *p, double);
+    if (work_x == NULL) {
+        PRINT_OUT("Error: Cannot allocate memory\n");
+        return;
+    }
+    double* restrict work_y = (double*) R_Calloc(*n, double);
+    if (work_y == NULL) {
+        PRINT_OUT("Error: Cannot allocate memory\n");
+        R_Free(work_x);
+        return;
+    }
+
     workarray wwork;
     workarray *work = &wwork;
     work->work_x = work_x;
@@ -85,7 +95,13 @@ void cov_reg_model(double *resid, double *x, double *xwgt, double *robwgt,
     F77_CALL(dgeqrf)(n, p, x, n, work_x, work_y, &lwork, &info);
     lwork = (int) work_y[0];
     work->lwork = lwork;
-    double* restrict work_lapack = (double*) Calloc(lwork, double);
+
+    double* restrict work_lapack = (double*) R_Calloc(lwork, double);
+    if (work_lapack == NULL) {
+        PRINT_OUT("Error: Cannot allocate memory\n");
+        R_Free(work_x); R_Free(work_y);
+        return;
+    }
     work->work_lapack = work_lapack;
 
     // psi and psi-prime functions
@@ -128,7 +144,7 @@ void cov_reg_model(double *resid, double *x, double *xwgt, double *robwgt,
     Memcpy(x, work_x, *p * *p);
 
 clean_up:
-    Free(work_lapack); Free(work_x); Free(work_y);
+    R_Free(work_lapack); R_Free(work_x); R_Free(work_y);
 }
 
 /******************************************************************************\
@@ -445,9 +461,23 @@ void cov_reg_design(double *x, double *w, double *xwgt, double *resid,
     double d_one = 1.0, d_zero = 0.0;
     *ok = 1;
     // allocate memory
-    double* M = (double*) Calloc(*p * *p, double);
-    double* work_pp = (double*) Calloc(*p * *p, double);
-    double* work_np = (double*) Calloc(*n * *p, double);
+    double* M = (double*) R_Calloc(*p * *p, double);
+    if (M == NULL) {
+        PRINT_OUT("Error: Cannot allocate memory\n");
+        return;
+    }
+    double* work_pp = (double*) R_Calloc(*p * *p, double);
+    if (work_pp == NULL) {
+        PRINT_OUT("Error: Cannot allocate memory\n");
+        R_Free(M);
+        return;
+    }
+    double* work_np = (double*) R_Calloc(*n * *p, double);
+    if (work_np == NULL) {
+        PRINT_OUT("Error: Cannot allocate memory\n");
+        R_Free(M); R_Free(work_pp);
+        return;
+    }
 
     // GM-estimators
     if (*type == 1) {                   // Mallows GM-estimator
@@ -482,7 +512,8 @@ void cov_reg_design(double *x, double *w, double *xwgt, double *resid,
     // U is upper triangular
     F77_CALL(dpotrf)("U", p, M, p, &info FCONE);
     if (info != 0) {
-        PRINT_OUT("Error in dpotrf (M matrix)\n");
+        PRINT_OUT("Error: %s\n",
+                robsurvey_error(ROBSURVEY_ERROR_CHOLESKY_DPOTRF));
         *ok = 0;
         goto clean_up;
     }
@@ -491,7 +522,8 @@ void cov_reg_design(double *x, double *w, double *xwgt, double *resid,
     // Cholesky factor of M)
     F77_CALL(dpotri)("U", p, M, p, &info FCONE);
     if (info != 0) {
-        PRINT_OUT("Error in dpotri (M matrix)\n");
+        PRINT_OUT("Error: %s\n",
+                robsurvey_error(ROBSURVEY_ERROR_CHOLESKY_DPOTRI));
         *ok = 0;
         goto clean_up;
     }
@@ -508,7 +540,7 @@ void cov_reg_design(double *x, double *w, double *xwgt, double *resid,
     // covariance matrix
 
 clean_up:
-    Free(work_pp); Free(work_np); Free(M);
+    R_Free(work_pp); R_Free(work_np); R_Free(M);
 }
 #undef _POWER2
 #undef PRINT_OUT
